##  Editing Transformation Items in Bulk
You can edit defined transformation items in bulk by selecting the table view mode. This simplifies the management of transformations, particularly when dealing with a large number of changes, which can be tedious and time-consuming.
In the table view mode, you can edit any field, including the name, description, dates, fact sheets, tags, and any field values of the transformation items. Additionally, you can filter transformation items based on transformation type, sort the list by columns, and delete transformation items that are not needed.
To edit transformation items in bulk, do the following:
  1. In the Transformations tab of the initiative fact sheet, switch to table view mode by selecting the table icon next to the Collapse all button.
  2. By default, transformations of only one type are listed in the table. From the drop-down menu above the table, select the type of transformations to be listed.
  3. Click Edit, and make the necessary changes in the cells.
     * You can copy and paste information from cells and autofill columns by pulling down the drag handle at the bottom right corner of a cell.
     * While editing completion dates, you can choose between dates or milestones.
     * You can delete a transformation item by right-clicking and selecting Delete Transformation.
  4. Click Save to complete.


![Editing Transformation Items in Bulk](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274924917a441014a0fef28a33397327_LowRes.gif)
Editing Transformation Items in Bulk
